import java.io.*;
import java.util.*;
import org.jdom.input.SAXBuilder;
import org.jdom.xpath.XPath;
import org.jdom.*;

/** Code to select and print some subset of an HTML file using XPath.
 *
 * Compile with Java 1.6.0:
 *  javac -cp jaxen-jdom.jar\;jaxen-core.jar\;saxpath.jar\;jdom.jar\;tagsoup-1.1.3.jar\;. filter.java
 *
 * Run with:
 *  java -cp jaxen-jdom.jar\;jaxen-core.jar\;saxpath.jar\;jdom.jar\;tagsoup-1.1.3.jar\;. filter weather.html "/html/body"
 *
 * An example XPath expression for the supplied weather.html file is:
 *  "/html/body/table[3]/tbody/tr[1]/td[5]/table/tbody/tr[2]/td[1]/div[@id='day1sym']/center/img/@src"
 *
 * Ideally the XPath expression would be the following, but id isn't fully
 *  supported: "id('day1sym')/center/img/@src"
 *
 * @author Michael McTernan, Michael.McTernan.2001@cs.bris.ac.uk
 */
public class filter
{
    public final static void main(String[] args) throws Exception
    {
        if(args.length < 2)
        {
            System.out.println("Usage: java filter <file.html> <xpath>");
            System.exit(0);
        }

        SAXBuilder builder = new SAXBuilder("org.ccil.cowan.tagsoup.Parser");
        Document   doc     = stripNamespace(builder.build(new File(args[0])));
        XPath      xp      = XPath.newInstance(args[1]);

        List l = xp.selectNodes(doc);

        System.out.println("List: " + l);

        for(Object o : l)
        {
            System.out.println(o);
        }
    }


    /** Strip the namespace from all nodes in the passed Document.
     * @return The same document as passed in, but with all namespace data
     *          removed.
     */
    static Document stripNamespace(Document d)
    {
        stripNamespace(d.getDescendants());

        return d;
    }


    static void stripNamespace(Iterator i)
    {
        while(i.hasNext())
        {
            stripNamespace(i.next());
        }
    }


    static void stripNamespace(Object o)
    {
        if(o instanceof Element)
        {
            stripNamespace((Element) o);
        }
        else if(o instanceof Attribute)
        {
            stripNamespace((Attribute) o);
        }
        else if(o instanceof Document)
        {
            stripNamespace((Document) o);
        }
        else if(o instanceof Text || o instanceof Comment)
        {
            /* Nothing to do */
        }
        else
        {
            /* Something else probably needs handling */
            System.out.println(o);
        }
    }

    static void stripNamespace(Element e)
    {
        e.setNamespace(null);
        stripNamespace(e.getAttributes().iterator());
        stripNamespace(e.getDescendants());
    }


    static void stripNamespace(Attribute a)
    {
        a.setNamespace(null);
    }
}


/* END OF FILE */